@@ -41,7 +41,7 @@
 //! - `lib.rs`, the generated code.
 //!
 //! All these files must be included in the same device crate. The `lib.rs` file contains several
-//! inlined modules and its not formatted. It's recommend to split it out using the [`form`] tool
+//! inlined modules and its not formatted. It's recommended to split it out using the [`form`] tool
 //! and then format the output using `rustfmt` / `cargo fmt`:
 //!
 //! [`form`]: https://crates.io/crates/form
@@ -99,30 +99,32 @@
 //!
 //! $ xmllint -format out.svd > msp430g2553.svd
 //!
-//! $ svd2rust --target=msp430 -i msp430g2553.svd
+//! $ svd2rust -g --target=msp430 -i msp430g2553.svd
 //!
 //! $ rm -rf src
 //!
 //! $ form -i lib.rs -o src/ && rm lib.rs
 //!
+//! $ mv generic.rs src/
+//!
 //! $ cargo fmt
 //! ```
 //!
 //! The resulting crate must provide opt-in "rt" feature and depend on these crates: `msp430`
-//! v0.2.x, `msp430-rt` v0.2.x, and `vcell` v0.1.x. If the `--nightly` flag is provided to
-//! `svd2rust`, then `msp430-atomic` v0.1.2 is also needed. Furthermore the "device" feature of
+//! v0.3.x, `msp430-rt` v0.3.x, and `vcell` v0.1.x. If the `--nightly` flag is provided to
+//! `svd2rust`, then `msp430-atomic` v0.1.4 is also needed. Furthermore the "device" feature of
 //! `msp430-rt` must be enabled when the "rt" feature is enabled. The `Cargo.toml` of the device
 //! crate will look like this:
 //!
 //! ``` toml
 //! [dependencies]
-//! msp430 = "0.2.0"
+//! msp430 = "0.3.0"
 //! vcell = "0.1.0"
-//! msp430-atomic = "0.1.2" # Only when using the --nightly flag
+//! msp430-atomic = "0.1.4" # Only when using the --nightly flag
 //!
 //! [dependencies.msp430-rt]
 //! optional = true
-//! version = "0.2.0"
+//! version = "0.3.0"
 //!
 //! [features]
 //! rt = ["msp430-rt/device"]
@@ -500,10 +502,10 @@
 #![recursion_limit = "128"]
 
 use quote::quote;
-use svd_parser as svd;
+use svd_parser::svd;
 
-mod generate;
-mod util;
+pub mod generate;
+pub mod util;
 
 pub use crate::util::{Config, Target};
 
@@ -519,7 +521,8 @@ pub struct DeviceSpecific {
     pub build_rs: String,
 }
 
-use anyhow::Result;
+use anyhow::{Context, Result};
+
 #[derive(Debug, thiserror::Error)]
 pub enum SvdError {
     #[error("Cannot format crate")]
@@ -529,13 +532,13 @@ pub enum SvdError {
 }
 
 /// Generates rust code for the specified svd content.
-pub fn generate(xml: &str, config: &Config) -> Result<Generation> {
+pub fn generate(input: &str, config: &Config) -> Result<Generation> {
     use std::fmt::Write;
 
-    let device = svd::parse(xml)?;
+    let device = load_from(input, config)?;
     let mut device_x = String::new();
     let items =
-        generate::device::render(&device, &config, &mut device_x).or(Err(SvdError::Render))?;
+        generate::device::render(&device, config, &mut device_x).or(Err(SvdError::Render))?;
 
     let mut lib_rs = String::new();
     writeln!(
@@ -562,6 +565,30 @@ pub fn generate(xml: &str, config: &Config) -> Result<Generation> {
     })
 }
 
+/// Load a [Device] from a string slice with given [config](crate::util::Config).
+pub fn load_from(input: &str, config: &crate::util::Config) -> Result<svd::Device> {
+    use self::util::SourceType;
+    use svd_parser::ValidateLevel;
+
+    Ok(match config.source_type {
+        SourceType::Xml => {
+            let mut parser_config = svd_parser::Config::default();
+            parser_config.validate_level = if config.strict {
+                ValidateLevel::Strict
+            } else {
+                ValidateLevel::Weak
+            };
+
+            svd_parser::parse_with_config(input, &parser_config)
+                .with_context(|| "Error parsing SVD XML file".to_string())?
+        }
+        SourceType::Yaml => serde_yaml::from_str(input)
+            .with_context(|| "Error parsing SVD YAML file".to_string())?,
+        SourceType::Json => serde_json::from_str(input)
+            .with_context(|| "Error parsing SVD JSON file".to_string())?,
+    })
+}
+
 /// Assigns a handler to an interrupt
 ///
 /// **NOTE** The `interrupt!` macro on Cortex-M and MSP430 device crates is closer in syntax to the
